@@ -1,14 +1,45 @@
+import itertools
+
 from ufo2ft.constants import (
     COLOR_LAYER_MAPPING_KEY,
     COLOR_LAYERS_KEY,
     COLOR_PALETTES_KEY,
 )
-from ufo2ft.filters import loadFilters
+from ufo2ft.filters import isValidFilter, loadFilters
 from ufo2ft.filters.decomposeComponents import DecomposeComponentsFilter
+from ufo2ft.filters.decomposeTransformedComponents import (
+    DecomposeTransformedComponentsFilter,
+)
 from ufo2ft.fontInfoData import getAttrWithFallback
 from ufo2ft.util import _GlyphSet
 
 
+def _load_custom_filters(ufo, filters=None):
+    # Args:
+    #   ufo: Font
+    #   filters: Optional[List[Union[Filter, EllipsisType]]])
+    # Returns: List[Filter]
+
+    # by default, load the filters from the lib; ellipsis is used as a placeholder
+    # so one can optionally insert additional filters=[f1, ..., f2] either
+    # before or after these, or override them by omitting the ellipsis.
+    if filters is None:
+        filters = [...]
+    seen_ellipsis = False
+    result = []
+    for f in filters:
+        if f is ...:
+            if seen_ellipsis:
+                raise ValueError("ellipsis not allowed more than once")
+            result.extend(itertools.chain(*loadFilters(ufo)))
+            seen_ellipsis = True
+        else:
+            if not isValidFilter(type(f)):
+                raise TypeError(f"Invalid filter: {f!r}")
+            result.append(f)
+    return result
+
+
 class BasePreProcessor:
     """Base class for objects that performs pre-processing operations on
     the UFO glyphs, such as decomposing composites, removing overlaps, or
@@ -26,8 +57,17 @@ class BasePreProcessor:
     initialization of the default filters.
 
     Custom filters can be applied before or after the default filters.
-    These are specified in the UFO lib.plist under the private key
+    These can be specified in the UFO lib.plist under the private key
     "com.github.googlei18n.ufo2ft.filters".
+    Alternatively the optional ``filters`` parameter can be used. This is a
+    list of filter instances (subclasses of BaseFilter) that overrides
+    those defined in the UFO lib. The list can be empty, meaning no custom
+    filters are run. If ``filters`` contain the special value ``...`` (i.e.
+    the actual ``ellipsis`` singleton, not the str literal '...'), then all
+    the filters from the UFO lib are loaded in its place. This allows to
+    insert additional filters before or after those already defined in the
+    UFO lib, as opposed to discard/replace them which is the default behavior
+    when ``...`` is absent.
     """
 
     def __init__(
@@ -37,7 +77,7 @@ class BasePreProcessor:
         layerName=None,
         skipExportGlyphs=None,
         filters=None,
-        **kwargs
+        **kwargs,
     ):
         self.ufo = ufo
         self.inplace = inplace
@@ -46,11 +86,10 @@ class BasePreProcessor:
             ufo, layerName, copy=not inplace, skipExportGlyphs=skipExportGlyphs
         )
         self.defaultFilters = self.initDefaultFilters(**kwargs)
-        if filters is None:
-            self.preFilters, self.postFilters = loadFilters(ufo)
-        else:
-            self.preFilters = [f for f in filters if f.pre]
-            self.postFilters = [f for f in filters if not f.pre]
+
+        filters = _load_custom_filters(ufo, filters)
+        self.preFilters = [f for f in filters if f.pre]
+        self.postFilters = [f for f in filters if not f.pre]
 
     def initDefaultFilters(self, **kwargs):
         return []  # pragma: no cover
@@ -239,6 +278,8 @@ class TTFInterpolatablePreProcessor:
         assert len(ufos) == len(layerNames)
         self.layerNames = layerNames
 
+        # For each UFO, make a mapping of name to glyph object (and ensure it
+        # contains none of the glyphs to be skipped, or any references to it).
         self.glyphSets = [
             _GlyphSet.from_layer(
                 ufo, layerName, copy=not inplace, skipExportGlyphs=skipExportGlyphs
@@ -253,24 +294,37 @@ class TTFInterpolatablePreProcessor:
         self._reverseDirection = reverseDirection
         self._rememberCurveType = rememberCurveType
 
-        self.preFilters, self.postFilters = [], []
-        if filters is None:
-            for ufo in ufos:
-                pre, post = loadFilters(ufo)
-                self.preFilters.append(pre)
-                self.postFilters.append(post)
-        else:
-            pre = [f for f in filters if f.pre]
-            post = [f for f in filters if not f.pre]
-            for _ in ufos:
-                self.preFilters.append(pre)
-                self.postFilters.append(post)
+        self.defaultFilters = []
+        for ufo in ufos:
+            self.defaultFilters.append([])
+            _init_explode_color_layer_glyphs_filter(ufo, self.defaultFilters[-1])
+
+        filterses = [_load_custom_filters(ufo, filters) for ufo in ufos]
+        self.preFilters = [[f for f in filters if f.pre] for filters in filterses]
+        self.postFilters = [[f for f in filters if not f.pre] for filters in filterses]
 
     def process(self):
         from cu2qu.ufo import fonts_to_quadratic
 
+        needs_decomposition = set()
+
         # first apply all custom pre-filters
         for funcs, ufo, glyphSet in zip(self.preFilters, self.ufos, self.glyphSets):
+            for func in funcs:
+                if isinstance(func, DecomposeTransformedComponentsFilter):
+                    needs_decomposition |= func(ufo, glyphSet)
+                else:
+                    func(ufo, glyphSet)
+
+        # If we decomposed a glyph in some masters, we must ensure it is decomposed in
+        # all masters. (https://github.com/googlefonts/ufo2ft/issues/507)
+        if needs_decomposition:
+            decompose = DecomposeComponentsFilter(include=needs_decomposition)
+            for ufo, glyphSet in zip(self.ufos, self.glyphSets):
+                decompose(ufo, glyphSet)
+
+        # then apply all default filters
+        for funcs, ufo, glyphSet in zip(self.defaultFilters, self.ufos, self.glyphSets):
             for func in funcs:
                 func(ufo, glyphSet)
 
@@ -282,6 +336,9 @@ class TTFInterpolatablePreProcessor:
             remember_curve_type=self._rememberCurveType and self.inplace,
         )
 
+        # TrueType fonts cannot mix contours and components, so pick out all glyphs
+        # that have contours (`bool(len(g)) == True`) and decompose their
+        # components, if any.
         decompose = DecomposeComponentsFilter(include=lambda g: len(g))
         for ufo, glyphSet in zip(self.ufos, self.glyphSets):
             decompose(ufo, glyphSet)
